/*
 * CS43L22.c
 *
 *  Created on: Apr 3, 2021
 *      Author: Think
 */
#include "CS43L22.h"

//CS43L22 I2C address
static const uint8_t CS43L22_ADDR = 0x4A << 1;

//CS43L22 register address array for easy register dump..
static const uint8_t REG_ARRAY[CS43L22_RESGISTER_COUNT] = {0x01, 0x02, 0x04,
									0x05, 0x06, 0x07,
									0x08, 0x09, 0x0A,
									0x0C, 0x0D, 0x0E,
									0x0F, 0x14, 0x15,
									0x1A, 0x1B, 0x1C,
									0x1D, 0x1E, 0x1F,
									0x20, 0x21, 0x22,
									0x23, 0x24, 0x25,
									0x26, 0x27, 0x28,
									0x29, 0x2E, 0x2F,
									0x30, 0x31, 0x34};

//CS43L22 36 register definition enum
typedef enum
{
	_ID = 0,
	_POWER_CTL_1,
	_POWER_CTL_2,
	_CLOCKING_CTL,
	_INTERFACE_CTL_1,
	_INTERFACE_CTL_2,
	_PASSTHROUGH_A_SELECT,
	_PASSTHROUGH_B_SELECT,
	_ANALOG_ZC_AND_SR_SETTING,
	_PASSTHROUGH_GANG_CONTROL,
	_PLAYBACK_CTL_1,
	_MISC_CTL,
	_PLAYBACK_CTL_2,
	_PASSTHROUGH_A_VOL,
	_PASSTHROUGH_B_VOL,
	_PCMA_VOL,
	_PCMB_VOL,
	_BEEP_FREQ_ON_TIME,
	_BEEP_VOL_OFF_TIME,
	_BEEP_TONE_CFG,
	_TONE_CTL,
	_MASTER_A_VOL,
	_MASTER_B_VOL,
	_HEADPHONE_A_VOLUME,
	_HEADPHONE_B_VOLUME,
	_SPEAKER_A_VOLUME,
	_SPEAKER_B_VOLUME,
	_CHANNEL_MIXER_AND_SWAP,
	_LIMIT_CTL_1_THRESHOLDS,
	_LIMIT_CTL_2_THRESHOLDS,
	_LIMITER_ATTACK_RATE,
	_OVERFLOW_AND_CLOCK_STATUS,
	_BATTERY_COMPENSATION,
	_VP_BATTERY_LEVEL,
	_SPEAKER_STATUS,
	_CHARGE_PUMP_FREQUENCY,
} CS43L22_REGISTER_e;

//Driver function definition
bool CS43L22_Init(CS43L22 *device, I2C_HandleTypeDef *i2cHandler)
{
	device->i2cHandler = i2cHandler;

	//We check that the reset pin is not low...
	HAL_GPIO_WritePin(GPIOD, GPIO_PIN_4, GPIO_PIN_SET);

	return true;
}

const uint8_t * const CS43L22_GetRegisterArray(void)
{
	return REG_ARRAY;
}

bool CS43L22_Reset(CS43L22 *device)
{
	HAL_GPIO_WritePin(GPIOD, GPIO_PIN_4, GPIO_PIN_RESET);
	HAL_Delay(50);
	HAL_GPIO_WritePin(GPIOD, GPIO_PIN_4, GPIO_PIN_SET);
	return true;
}

bool CS43L22_GetDeviceID(CS43L22 *device, uint8_t *chipID, uint8_t *chipREVID)
{
	uint8_t data;
	if(!CS43L22_ReadRegister(device, ID, &data))
		return false;

	*chipID = data >> 3;
	*chipREVID = data & 0x07;

	return true;
}

bool CS43L22_ReadRegister(CS43L22 *device, uint8_t registerAddr, uint8_t *data)
{
	HAL_StatusTypeDef status = HAL_I2C_Master_Transmit(device->i2cHandler, CS43L22_ADDR, &registerAddr, 1, HAL_MAX_DELAY);
	if(status != HAL_OK)
		return false;
	return HAL_I2C_Master_Receive(device->i2cHandler, CS43L22_ADDR, data, 1, HAL_MAX_DELAY) == HAL_OK ? true : false;
}

bool CS43L22_WriteRegister(CS43L22 *device, uint8_t registerAddr, uint8_t data)
{
	uint8_t regAndData[] = {registerAddr, data};
	return HAL_I2C_Master_Transmit(device->i2cHandler, CS43L22_ADDR, regAndData, 2, HAL_MAX_DELAY) == HAL_OK ? true : false;
}

bool CS43L22_RegisterDump(CS43L22 *device, uint8_t registers[36])
{
	if(!registers)
		return false;

	for(uint8_t i = 0; i < sizeof(REG_ARRAY); i++)
	{
		if(!CS43L22_ReadRegister(device, REG_ARRAY[i], registers + i))
			return false;
	}

	return true;
}
